@@ -16,6 +16,11 @@ class Mongodb:
     TRANSACTION_COLLECTION = "transactions"
     AREA_REPORTS_BY_DAY_COLLECTION = "area_report_by_day"
     COUNTRIES_COLLECTION = 'countries'
+    ORG_CONFIG_COLLECTION = 'org_config'
+    COUNTERS_COLLECTION = 'counters'
+    EVENTS_COLLECTION = 'events'
+    DAILY_REPORTS_COLLECTION = 'daily_reports'
+
 
     def __init__(self, db_name):
         try:
